#!/bin/bash
#########################################################################
# Script to toggle an experimental feature on a host
#
# Usage:
#   toggle-experimental-feature.sh <feature>
#
# where:
#   <feature> is the name of the feature to toggle
#
#########################################################################

set -e

function check_syntax {
  local ARG_NUM=$1
  local CALLER_SCRIPT=$2

  if [ "${ARG_NUM}" != 1 ] ; then
    echo "Syntax: ${CALLER_SCRIPT} <feature>"
    exit 1
  fi
}

CALLER="$(basename "$0")"

case ${CALLER} in
  xe-enable-experimental-feature)
    check_syntax $# ${CALLER}
    ENABLE=1
    ;;
  xe-disable-experimental-feature)
    check_syntax $# ${CALLER}
    ENABLE=0
    ;;
  *)
    echo "Usage:"
    echo "  xe-enable-experimental-feature <feature>"
    echo "or"
    echo "  xe-disable-experimental-feature <feature>"
    exit 1
esac

FEATURE=$1
FEATURE_DIR="/etc/xensource/features.d"
FEATURE_PATH="${FEATURE_DIR}/${FEATURE}"
SCRIPT_PATH="${FEATURE_DIR}/${FEATURE}.sh"

. /etc/xensource-inventory

if [ -f ${FEATURE_PATH} ]; then

  if [ -f ${SCRIPT_PATH} ]; then
    . ${SCRIPT_PATH} ${ENABLE}
  fi

  echo ${ENABLE} > ${FEATURE_PATH}

  CURRENT_EDITION=$(xe host-param-get param-name=edition uuid=${INSTALLATION_UUID})
  xe host-apply-edition edition=${CURRENT_EDITION} host-uuid=${INSTALLATION_UUID}

else
  echo Unknown feature: ${FEATURE}
  exit 1
fi
